---
task_categories:
- $task_category
---

# Dataset card for $name

## Table of Contents
- [Table of Contents](#table-of-contents)
- [Dataset description](#dataset-description)
- [Dataset categories](#dataset-categories)

## Dataset description

- **Homepage:** $segments_url

$short_description

This dataset was created using [Segments.ai](https://segments.ai). It can be found [here]($segments_url).

## Dataset categories
| Id  | Name | Description |
| --- | ---- | ----------- |
$taxonomy_table
